/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (c) 2019-2020, The Linux Foundation. All rights reserved.
 */

#ifndef _CAM_CUSTOM_CSID_480_H_
#define _CAM_CUSTOM_CSID_480_H_

#include "cam_ife_csid_common.h"
#include "cam_ife_csid_hw_ver1.h"

#define CAM_CSID_VERSION_V480                 0x40080000

static struct cam_ife_csid_ver1_path_reg_info
	cam_custom_csid_480_udi_0_reg_offset = {
	.irq_status_addr                 = 0x30,
	.irq_mask_addr                   = 0x34,
	.irq_clear_addr                  = 0x38,
	.irq_set_addr                    = 0x3c,
	.cfg0_addr                       = 0x200,
	.cfg1_addr                       = 0x204,
	.ctrl_addr                       = 0x208,
	.frm_drop_pattern_addr           = 0x20c,
	.frm_drop_period_addr            = 0x210,
	.irq_subsample_pattern_addr      = 0x214,
	.irq_subsample_period_addr       = 0x218,
	.hcrop_addr                      = 0x21c,
	.vcrop_addr                      = 0x220,
	.pix_drop_pattern_addr           = 0x224,
	.pix_drop_period_addr            = 0x228,
	.line_drop_pattern_addr          = 0x22c,
	.line_drop_period_addr           = 0x230,
	.rst_strobes_addr                = 0x240,
	.status_addr                     = 0x250,
	.misr_val0_addr                  = 0x254,
	.misr_val1_addr                  = 0x258,
	.misr_val2_addr                  = 0x25c,
	.misr_val3_addr                  = 0x260,
	.format_measure_cfg0_addr        = 0x270,
	.format_measure_cfg1_addr        = 0x274,
	.format_measure0_addr            = 0x278,
	.format_measure1_addr            = 0x27c,
	.format_measure2_addr            = 0x280,
	.timestamp_curr0_sof_addr        = 0x290,
	.timestamp_curr1_sof_addr        = 0x294,
	.timestamp_prev0_sof_addr        = 0x298,
	.timestamp_prev1_sof_addr        = 0x29c,
	.timestamp_curr0_eof_addr        = 0x2a0,
	.timestamp_curr1_eof_addr        = 0x2a4,
	.timestamp_prev0_eof_addr        = 0x2a8,
	.timestamp_prev1_eof_addr        = 0x2ac,
	.err_recovery_cfg0_addr          = 0x2b0,
	.err_recovery_cfg1_addr          = 0x2b4,
	.err_recovery_cfg2_addr          = 0x2b8,
	.multi_vcdt_cfg0_addr            = 0x2bc,
	.byte_cntr_ping_addr             = 0x2e0,
	.byte_cntr_pong_addr             = 0x2e4,
	/* configurations */
	.plain_fmt_shift_val             = 10,
	.crop_v_en_shift_val             = 6,
	.crop_h_en_shift_val             = 5,
	.ccif_violation_en               = 1,
	.overflow_ctrl_en                = 0,
};

static struct cam_ife_csid_ver1_path_reg_info
	cam_custom_csid_480_udi_1_reg_offset = {
	.irq_status_addr                 = 0x40,
	.irq_mask_addr                   = 0x44,
	.irq_clear_addr                  = 0x48,
	.irq_set_addr                    = 0x4c,
	.cfg0_addr                       = 0x300,
	.cfg1_addr                       = 0x304,
	.ctrl_addr                       = 0x308,
	.frm_drop_pattern_addr           = 0x30c,
	.frm_drop_period_addr            = 0x310,
	.irq_subsample_pattern_addr      = 0x314,
	.irq_subsample_period_addr       = 0x318,
	.hcrop_addr                      = 0x31c,
	.vcrop_addr                      = 0x320,
	.pix_drop_pattern_addr           = 0x324,
	.pix_drop_period_addr            = 0x328,
	.line_drop_pattern_addr          = 0x32c,
	.line_drop_period_addr           = 0x330,
	.rst_strobes_addr                = 0x340,
	.status_addr                     = 0x350,
	.misr_val0_addr                  = 0x354,
	.misr_val1_addr                  = 0x358,
	.misr_val2_addr                  = 0x35c,
	.misr_val3_addr                  = 0x360,
	.format_measure_cfg0_addr        = 0x370,
	.format_measure_cfg1_addr        = 0x374,
	.format_measure0_addr            = 0x378,
	.format_measure1_addr            = 0x37c,
	.format_measure2_addr            = 0x380,
	.timestamp_curr0_sof_addr        = 0x390,
	.timestamp_curr1_sof_addr        = 0x394,
	.timestamp_prev0_sof_addr        = 0x398,
	.timestamp_prev1_sof_addr        = 0x39c,
	.timestamp_curr0_eof_addr        = 0x3a0,
	.timestamp_curr1_eof_addr        = 0x3a4,
	.timestamp_prev0_eof_addr        = 0x3a8,
	.timestamp_prev1_eof_addr        = 0x3ac,
	.err_recovery_cfg0_addr          = 0x3b0,
	.err_recovery_cfg1_addr          = 0x3b4,
	.err_recovery_cfg2_addr          = 0x3b8,
	.multi_vcdt_cfg0_addr            = 0x3bc,
	.byte_cntr_ping_addr             = 0x3e0,
	.byte_cntr_pong_addr             = 0x3e4,
	/* configurations */
	.mipi_pack_supported             = 1,
	.packing_fmt_shift_val           = 30,
	.plain_fmt_shift_val             = 10,
	.crop_v_en_shift_val             = 6,
	.crop_h_en_shift_val             = 5,
	.drop_v_en_shift_val             = 4,
	.drop_h_en_shift_val             = 3,
	.timestamp_en_shift_val          = 2,
	.ccif_violation_en               = 1,
	.format_measure_en_shift_val     = 1,
	.overflow_ctrl_en                = 0,
	.non_fatal_err_mask              = 0x2e000,
	.fatal_err_mask                  = 0x4,
	.overflow_ctrl_mode_val          = 0x8,
};

static struct cam_ife_csid_ver1_path_reg_info
	cam_custom_csid_480_udi_2_reg_offset = {
	.irq_status_addr                 = 0x50,
	.irq_mask_addr                   = 0x54,
	.irq_clear_addr                  = 0x58,
	.irq_set_addr                    = 0x5c,
	.cfg0_addr                       = 0x400,
	.cfg1_addr                       = 0x404,
	.ctrl_addr                       = 0x408,
	.frm_drop_pattern_addr           = 0x40c,
	.frm_drop_period_addr            = 0x410,
	.irq_subsample_pattern_addr      = 0x414,
	.irq_subsample_period_addr       = 0x418,
	.hcrop_addr                      = 0x41c,
	.vcrop_addr                      = 0x420,
	.pix_drop_pattern_addr           = 0x424,
	.pix_drop_period_addr            = 0x428,
	.line_drop_pattern_addr          = 0x42c,
	.line_drop_period_addr           = 0x430,
	.yuv_chroma_conversion_addr      = 0x434,
	.rst_strobes_addr                = 0x440,
	.status_addr                     = 0x450,
	.misr_val0_addr                  = 0x454,
	.misr_val1_addr                  = 0x458,
	.misr_val2_addr                  = 0x45c,
	.misr_val3_addr                  = 0x460,
	.format_measure_cfg0_addr        = 0x470,
	.format_measure_cfg1_addr        = 0x474,
	.format_measure0_addr            = 0x478,
	.format_measure1_addr            = 0x47c,
	.format_measure2_addr            = 0x480,
	.timestamp_curr0_sof_addr        = 0x490,
	.timestamp_curr1_sof_addr        = 0x494,
	.timestamp_prev0_sof_addr        = 0x498,
	.timestamp_prev1_sof_addr        = 0x49c,
	.timestamp_curr0_eof_addr        = 0x4a0,
	.timestamp_curr1_eof_addr        = 0x4a4,
	.timestamp_prev0_eof_addr        = 0x4a8,
	.timestamp_prev1_eof_addr        = 0x4ac,
	.err_recovery_cfg0_addr          = 0x4b0,
	.err_recovery_cfg1_addr          = 0x4b4,
	.err_recovery_cfg2_addr          = 0x4b8,
	.multi_vcdt_cfg0_addr            = 0x4bc,
	.byte_cntr_ping_addr             = 0x4e0,
	.byte_cntr_pong_addr             = 0x4e4,
	/* configurations */
	.plain_fmt_shift_val             = 10,
	.crop_v_en_shift_val             = 6,
	.crop_h_en_shift_val             = 5,
	.ccif_violation_en               = 1,
	.overflow_ctrl_en                = 0,
};

static struct cam_ife_csid_csi2_rx_reg_info
			cam_custom_csid_480_csi2_reg_info = {
	.irq_status_addr                 = 0x20,
	.irq_mask_addr                   = 0x24,
	.irq_clear_addr                  = 0x28,
	.irq_set_addr                    = 0x2c,

	/*CSI2 rx control */
	.cfg0_addr                       = 0x100,
	.cfg1_addr                       = 0x104,
	.capture_ctrl_addr               = 0x108,
	.rst_strobes_addr                = 0x110,
	.de_scramble_cfg0_addr           = 0x114,
	.de_scramble_cfg1_addr           = 0x118,
	.cap_unmap_long_pkt_hdr_0_addr   = 0x120,
	.cap_unmap_long_pkt_hdr_1_addr   = 0x124,
	.captured_short_pkt_0_addr       = 0x128,
	.captured_short_pkt_1_addr       = 0x12c,
	.captured_long_pkt_0_addr        = 0x130,
	.captured_long_pkt_1_addr        = 0x134,
	.captured_long_pkt_ftr_addr      = 0x138,
	.captured_cphy_pkt_hdr_addr      = 0x13c,
	.lane0_misr_addr                 = 0x150,
	.lane1_misr_addr                 = 0x154,
	.lane2_misr_addr                 = 0x158,
	.lane3_misr_addr                 = 0x15c,
	.total_pkts_rcvd_addr            = 0x160,
	.stats_ecc_addr                  = 0x164,
	.total_crc_err_addr              = 0x168,

	.rst_srb_all                     = 0x3FFF,
	.rst_done_shift_val              = 27,
	.irq_mask_all                    = 0xFFFFFFF,
	.misr_enable_shift_val           = 6,
	.vc_mode_shift_val               = 2,
	.capture_long_pkt_en_shift       = 0,
	.capture_short_pkt_en_shift      = 1,
	.capture_cphy_pkt_en_shift       = 2,
	.capture_long_pkt_dt_shift       = 4,
	.capture_long_pkt_vc_shift       = 10,
	.capture_short_pkt_vc_shift      = 15,
	.capture_cphy_pkt_dt_shift       = 20,
	.capture_cphy_pkt_vc_shift       = 26,
	.phy_num_mask                    = 0x3,
	.fatal_err_mask                  = 0x78000,
	.part_fatal_err_mask             = 0x1801800,
};

static struct cam_ife_csid_ver1_common_reg_info
			cam_custom_csid_480_cmn_reg_offset = {
	.hw_version_addr                 = 0x0,
	.cfg0_addr                       = 0x4,
	.ctrl_addr                       = 0x8,
	.reset_addr                      = 0xc,
	.rst_strobes_addr                = 0x10,

	.test_bus_ctrl_addr              = 0x14,
	.top_irq_status_addr             = 0x70,
	.top_irq_mask_addr               = 0x74,
	.top_irq_clear_addr              = 0x78,
	.top_irq_set_addr                = 0x7c,
	.irq_cmd_addr                    = 0x80,

	/*configurations */
	.major_version                   = 1,
	.minor_version                   = 7,
	.version_incr                    = 0,
	.num_udis                        = 3,
	.num_rdis                        = 0,
	.num_pix                         = 0,
	.num_ppp                         = 0,
	.rst_sw_reg_stb                  = 1,
	.rst_hw_reg_stb                  = 0x1e,
	.rst_sw_hw_reg_stb               = 0x1f,
	.path_rst_stb_all                = 0x7f,
	.rst_done_shift_val              = 1,
	.path_en_shift_val               = 31,
	.dt_id_shift_val                 = 27,
	.vc_shift_val                    = 22,
	.dt_shift_val                    = 16,
	.fmt_shift_val                   = 12,
	.ipp_irq_mask_all                = 0,
	.rdi_irq_mask_all                = 0,
	.ppp_irq_mask_all                = 0,
	.udi_irq_mask_all                = 0x7FFF,
	.measure_en_hbi_vbi_cnt_mask     = 0xC,
	.num_bytes_out_shift_val         = 3,
};

static struct cam_ife_csid_ver1_reg_info cam_custom_csid_480_reg_offset = {
	.cmn_reg          = &cam_custom_csid_480_cmn_reg_offset,
	.csi2_reg         = &cam_custom_csid_480_csi2_reg_info,
	.ipp_reg          = NULL,
	.ppp_reg          = NULL,
	.rdi_reg = {
		NULL,
		NULL,
		NULL,
		NULL,
	},
	.udi_reg = {
		&cam_custom_csid_480_udi_0_reg_offset,
		&cam_custom_csid_480_udi_1_reg_offset,
		&cam_custom_csid_480_udi_2_reg_offset,
	},
	.tpg_reg = NULL,
};

#endif /*_CAM_IFE_CSID_480_H_ */
